Learn R Programming

cardidates (version 0.4.2)

aweibull7: Six-Parametric Weibull Function with Additive Shift

Description

A special version of the six-parametric Weibull function which has a 7th parameter for additive vertical shifting. It is intended mainly for internal use.

Usage

fweibull6(x, p)

aweibull7(p, lower = 0, upper = 365)

Arguments

x
vector of function arguments
p
vector of function parameters, see weibull6 for an explanation of parameters p[1] ...p[6]; p[7] is an additive constant.
lower
lower limit of the cumulative (integrated) function,
upper
upper limit of the cumulative (integrated) function.

Value

  • fweibull7 gives the function and aweibull7 its definite integral (cumulative function or area under curve). Note that integration is done numerically and that the function returns a scalar, not a vector.

Details

The function is intended for internal use, i.e. for separate area calculations of the left and right branches.

See Also

weibull6, fitweibull, CDW, cardidates